==> docfbe_2_2_32_56.zip: docfbe_2_2_32_56/source/TCFbEAdjustedWeightedSumWithMedianOfNeighbors.cpp <==
/*
    TCFbEAdjustedWeightedSumWithMedianOfNeighbors.cpp    June 6, 2004.

    Copyright (C) 2003-2004 CFbE Research Group,
    Software Engineering Laboratory,
    Graduate School of Information Science,
    Nara Institute of Science and Technology,
    All rights reserved.

    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2, (at your option) or
    any later version.

    This program is distributed in the hope that it will be useful, but
    WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with GNU Emacs; see the file COPYING.  If not, write to the
    Free Software Foundation, Inc., 59 Temple Place - Suite 330,
    Boston, MA 02111-1307, USA.
*/
//---------------------------------------------------------------------------
#pragma hdrstop

#include "TCFbEAdjustedWeightedSumWithMedianOfNeighbors.h"
//---------------------------------------------------------------------------
#pragma package(smart_init)
//---------------------------------------------------------------------------
// RXgN^
__fastcall TCFbEAdjustedWeightedSumWithMedianOfNeighbors::TCFbEAdjustedWeightedSumWithMedianOfNeighbors(void)
    : TCFbEWeightedSum()
{
}

//---------------------------------------------------------------------------
// fXgN^
__fastcall TCFbEAdjustedWeightedSumWithMedianOfNeighbors::~TCFbEAdjustedWeightedSumWithMedianOfNeighbors()
{
}

//---------------------------------------------------------------------------
// ȍ~Cprotected \bh
//---------------------------------------------------------------------------
// LbVNA
void __fastcall TCFbEAdjustedWeightedSumWithMedianOfNeighbors::ClearCash(void)
{
    TCFbEWeightedSum::ClearCash();
    this->CashEnabled = false;
}

//---------------------------------------------------------------------------
// q̒l𓾂
double __fastcall TCFbEAdjustedWeightedSumWithMedianOfNeighbors::GetNumerator(int NeighborIndex)
{
    if (!this->CashEnabled) {
        this->MedianOfNeighbors = TCFbENeighbor::GetMedianValueOfNeighborList(this->NeighborList);
    }

    TCFbENeighbor*    Neighbor = (TCFbENeighbor*)this->NeighborList->Items[NeighborIndex];
    return (Neighbor->Value - this->MedianOfNeighbors) *  Neighbor->Similarity;
}

//---------------------------------------------------------------------------
// \l𓾂
double __fastcall TCFbEAdjustedWeightedSumWithMedianOfNeighbors::GetPredictedValue(double Numerator, double Denominator)
{
    if (!this->CashEnabled) {
        this->MedianOfNeighbors = TCFbENeighbor::GetMedianValueOfNeighborList(this->NeighborList);
    }

    return this->MedianOfNeighbors + Numerator / Denominator;
}

//---------------------------------------------------------------------------

==> docfbe_2_3_39_68.zip: docfbe_2_3_39_68/source/TCFbEAdjustedWeightedSumWithMedianOfNeighbors.cpp <==
/*
    TCFbEAdjustedWeightedSumWithMedianOfNeighbors.cpp    June 6, 2004.

    Copyright (C) 2003-2004 CFbE Research Group,
    Software Engineering Laboratory,
    Graduate School of Information Science,
    Nara Institute of Science and Technology,
    All rights reserved.

    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2, (at your option) or
    any later version.

    This program is distributed in the hope that it will be useful, but
    WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with GNU Emacs; see the file COPYING.  If not, write to the
    Free Software Foundation, Inc., 59 Temple Place - Suite 330,
    Boston, MA 02111-1307, USA.
*/
//---------------------------------------------------------------------------
#pragma hdrstop

#include "TCFbEAdjustedWeightedSumWithMedianOfNeighbors.h"
//---------------------------------------------------------------------------
#pragma package(smart_init)
//---------------------------------------------------------------------------
// RXgN^
__fastcall TCFbEAdjustedWeightedSumWithMedianOfNeighbors::TCFbEAdjustedWeightedSumWithMedianOfNeighbors(void)
    : TCFbEWeightedSum()
{
}

//---------------------------------------------------------------------------
// fXgN^
__fastcall TCFbEAdjustedWeightedSumWithMedianOfNeighbors::~TCFbEAdjustedWeightedSumWithMedianOfNeighbors()
{
}

//---------------------------------------------------------------------------
// ȍ~Cprotected \bh
//---------------------------------------------------------------------------
// LbVNA
void __fastcall TCFbEAdjustedWeightedSumWithMedianOfNeighbors::ClearCash(void)
{
    TCFbEWeightedSum::ClearCash();
    this->CashEnabled = false;
}

//---------------------------------------------------------------------------
// q̒l𓾂
double __fastcall TCFbEAdjustedWeightedSumWithMedianOfNeighbors::GetNumerator(int NeighborIndex)
{
    if (!this->CashEnabled) {
        this->MedianOfNeighbors = TCFbENeighbor::GetMedianValueOfNeighborList(this->NeighborList);
    }

    TCFbENeighbor*    Neighbor = (TCFbENeighbor*)this->NeighborList->Items[NeighborIndex];
    return (Neighbor->GetValue() - this->MedianOfNeighbors) *  Neighbor->GetSimilarity();
}

//---------------------------------------------------------------------------
// \l𓾂
double __fastcall TCFbEAdjustedWeightedSumWithMedianOfNeighbors::GetPredictedValue(double Numerator, double Denominator)
{
    if (!this->CashEnabled) {
        this->MedianOfNeighbors = TCFbENeighbor::GetMedianValueOfNeighborList(this->NeighborList);
    }

    return this->MedianOfNeighbors + Numerator / Denominator;
}

//---------------------------------------------------------------------------
